@@ -8,7 +8,8 @@
 #' @param h number of periods for forecasting. If \code{xreg} is used, \code{h} is ignored and the number of forecast
 #' periods is set to the number of rows of \code{xreg}.
 #' @param xreg future values of regression variables (for use if one of the ensemble methods used
-#' in creating the hybrid forecast was \code{auto.arima}, \code{nnetar}, or \code{stlm} and the model(s) used \code{xreg} in the fit)
+#' in creating the hybrid forecast was \code{auto.arima}, \code{nnetar}, or \code{stlm} and the model(s) used \code{xreg} in the fit).
+#' It should be supplied as a matrix.
 #' @param level confidence level for prediction intervals. This can be expressed as a decimal between 0.0 and 1.0 or numeric
 #' between 0 and 100.
 #' @param fan if \code{TRUE}, level is set to \code{seq(51, 99, by = 3)}. This is suitable for fan plots.
@@ -21,7 +22,7 @@
 #' and the lowest prediction interval from all of the component models').
 #' @param ... other arguments passed to the individual \code{forecast} generic methods.
 #' @seealso \code{\link{hybridModel}}
-#' @details if \code{xreg} was used in construcing the \code{hybridModel},
+#' @details if \code{xreg} was used in constructing the \code{hybridModel},
 #' it must also be passed into \code{forecast.hybridModel}.
 #' \cr
 #' \cr
@@ -70,14 +71,14 @@ forecast.hybridModel <- function(object,
 
   # xreg should be a matrix and have same number of observations as the horizon
   if(!is.null(xreg)){
-    if(!is.matrix(xreg) && !is.data.frame(xreg)){
-      stop("The supplied xreg must be a matrix or data.frame.")
+    if(!is.matrix(xreg) && !is.numeric(xreg) && !is.data.frame(xreg)){
+      stop("The supplied xreg must be numeric, matrix, or data.frame.")
     }
     xreg <- as.matrix(xreg)
     if(!is.numeric(xreg)){
       stop("The supplied xreg must be numeric.")
     }
-    if(nrow(xreg) != h){
+    if(is.null(h) || nrow(xreg) != h){
       warning("The number of rows in xreg should match h. Setting h to nrow(xreg).")
       h <- nrow(xreg)
     }
@@ -132,7 +133,7 @@ forecast.hybridModel <- function(object,
     xregN <- xreg
     if(!object$xreg$nnetar){
       xregN <- NULL
-      }
+    }
     forecasts$nnetar <- forecast(object$nnetar, h = h, xreg = xregN, PI = PI, level = level, ...)
     forecasts$pointForecasts[, "nnetar"] <- forecasts$nnetar$mean
   }
@@ -142,7 +143,7 @@ forecast.hybridModel <- function(object,
     # xreg is only used in stlm if method = "arima"
     if(!object$xreg$stlm){
       xregS <- NULL
-      }
+    }
     forecasts$stlm <- forecast(object$stlm, h = h, xreg = xregS, level = level, ...)
     forecasts$pointForecasts[, "stlm"] <- forecasts$stlm$mean
   }
@@ -176,22 +177,22 @@ forecast.hybridModel <- function(object,
     piCombination <- match.arg(PI.combination)
     if(piCombination == "mean"){
       upperFunction <- lowerFunction <- mean
-    } else{
+    } else if(piCombination == "extreme"){
       upperFunction <- max
       lowerFunction <- min
     }
      nint <- length(level)
      upper <- lower <- matrix(NA, ncol = nint, nrow = length(finalForecast))
-     # Prediction intervals for nnetar do not currently work, so exclude these
-     piModels <- object$models#[object$models != "nnetar"]
+
+     piModels <- object$models
      # Produce each upper/lower limit
      for(i in 1:nint){
         # Produce the upper/lower limit for each model for a given level
         tmpUpper <- tmpLower <- matrix(NA, nrow = h, ncol = length(piModels))
         j2 <- 1
-        for(j in piModels){
-           tmpUpper[, j2] <- as.numeric(matrix(forecasts[[j]]$upper, nrow = h)[, i])
-           tmpLower[, j2] <- as.numeric(matrix(forecasts[[j]]$lower, nrow = h)[, i])
+        for(mod in piModels){
+           tmpUpper[, j2] <- as.numeric(matrix(forecasts[[mod]]$upper, nrow = h)[, i])
+           tmpLower[, j2] <- as.numeric(matrix(forecasts[[mod]]$lower, nrow = h)[, i])
            j2 <- j2 + 1
         }
         # Apply the function for reconciling the prediction intervals
